Summary:       Multichannel Digital Audio Workstation
Name:          ardour
Version:       2.4.1
Release:       1%{?dist}
Source:        http://ardour.org/files/releases/ardour-%{version}.tar.bz2
Source1:       ardour2.desktop
Source2:       ardour.script
Patch0:        ardour-2.1-SConstruct.patch
Patch1:        ardour-session.cc-no_stomp.patch
Patch2:        ardour-session.cc-_total_free_4k_blocks.patch
Patch3:        ardour-2.4-gcc43.patch
URL:           http://ardour.org
License:       GPLv2+
Group:         Applications/Multimedia

BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: scons, pkgconfig, libtool
BuildRequires: libxslt-devel, libgnomecanvas-devel, boost-devel
BuildRequires: alsa-lib-devel, jack-audio-connection-kit-devel
BuildRequires: liblo-devel, libusb-devel
BuildRequires: gettext >= 0.11.5
BuildRequires: libsamplerate-devel >= 0.0.13
BuildRequires: liblrdf-devel >= 0.3.1
BuildRequires: fftw-devel
BuildRequires: gtkmm24-devel >= 2.8
BuildRequires: libgnomecanvasmm26-devel >= 2.12
Requires: hicolor-icon-theme

BuildRequires:    desktop-file-utils
Requires(post):   desktop-file-utils
Requires(postun): desktop-file-utils

# for upgrade path from CCRMA ardour2 packages:
Provides: ardour2 = %{version}-%{release}
Obsoletes: ardour2 < %{version}-%release}

%description
Ardour is a multichannel hard disk recorder (HDR) and digital audio
workstation (DAW). It is capable of simultaneous recording 24 or more
channels of 32 bit audio at 48kHz. Ardour is intended to function as a
"professional" HDR system, replacing dedicated hardware solutions such
as the Mackie HDR, the Tascam 2424 and more traditional tape systems
like the Alesis ADAT series. It is also intended to provide the same
or better functionality as software systems such as ProTools,
Samplitude, Logic Audio, Nuendo and Cubase VST (we acknowledge these
and all other names as trademarks of their respective owners). It
supports MIDI Machine Control, and so can be controlled from any MMC
controller, such as the Mackie Digital 8 Bus mixer and many other
modern digital mixers.

%prep
%setup -q
%patch0 -p1
%patch1 -p0
%patch2 -p0
%patch3 -p1
for i in README.fr README.it TRANSLATORS; do
  iconv -f ISO-8859-1 -t UTF8 DOCUMENTATION/$i > DOCUMENTATION/$i.tmp
  mv DOCUMENTATION/$i.tmp DOCUMENTATION/$i
done

%build
# <sigh> ardours SConstruct script is a mess when it comes to determining
# opt_flags, so we override the lot using the ARCH= and DIST_TARGET= options

TARGETCPU="none"

%ifarch %{ix86}
ARCH_FLAGS="-DARCH_X86 -DBUILD_SSE_OPTIMIZATIONS"
TARGETCPU="i386"
%endif
%ifarch x86_64
ARCH_FLAGS="-DARCH_X86 -DBUILD_SSE_OPTIMIZATIONS -DUSE_X86_64_ASM"
TARGETCPU="x86_64"
%endif

scons %{?_smp_mflags} PREFIX=%{_prefix} LIBDIR=%{_lib} SYSLIBS=1 \
      DIST_TARGET="${TARGETCPU}" \
      ARCH="$RPM_OPT_FLAGS $ARCH_FLAGS -ffast-math"

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
scons DESTDIR=$RPM_BUILD_ROOT install

# Replace ardour2 with a script
install -dm 755 $RPM_BUILD_ROOT%{_libexecdir}
mv $RPM_BUILD_ROOT%{_bindir}/ardour2 $RPM_BUILD_ROOT%{_libexecdir}
install -m 755 %{SOURCE2} $RPM_BUILD_ROOT%{_bindir}/ardour2

# install the templates
install -dm 755 $RPM_BUILD_ROOT%{_datadir}/%{name}/templates
cp templates/*.template $RPM_BUILD_ROOT%{_datadir}/%{name}/templates
chmod 644 $RPM_BUILD_ROOT%{_datadir}/%{name}/templates/*

# copy icons to freedesktop locations
for s in 16 22 32 48 ; do
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${s}x${s}/apps
    cp $RPM_BUILD_ROOT%{_datadir}/ardour2/icons/ardour_icon_${s}px.png \
       $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${s}x${s}/apps/ardour.png
done

# install the desktop entry
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
desktop-file-install --vendor fedora              \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/applications \
  %{SOURCE1}

%find_lang gtk2_ardour
cat gtk2_ardour.lang > ardour.lang
%find_lang libardour2
cat libardour2.lang >> ardour.lang
%find_lang libgtkmm2ext
cat libgtkmm2ext.lang >> ardour.lang

%clean
rm -rf $RPM_BUILD_ROOT

%post
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
   %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%postun
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
   %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%files -f ardour.lang
%defattr(-,root,root,-)
%doc README COPYING DOCUMENTATION
%config(noreplace) %{_sysconfdir}/ardour2
%{_bindir}/ardour2
%{_libexecdir}/ardour2
%{_libdir}/ardour2/
%{_datadir}/ardour2/
%{_datadir}/ardour/
%{_datadir}/icons/hicolor/*/apps/ardour.png
%{_datadir}/applications/fedora-ardour2.desktop

%changelog
* Thu Apr 10 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 2.4.1-1
- New upstream release 2.4.1

* Mon Apr  7 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 2.4-1
- New upstream release 2.4
- Fix building with gcc-4.3, patch by Christopher Aillon (bz 434119, 440933)
- Switch to using system libraries, as the included ones don't compile with
  gcc-4.3 (bz 339391)

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.2-4
- Autorebuild for GCC 4.3

* Wed Jan 23 2008 Anthony Green <green@redhat.com> 2.2-3
- Fix tagging glitch.

* Tue Jan 22 2008 Anthony Green <green@redhat.com> 2.2-2
- Fix wrapper script.

* Thu Jan 17 2008 Anthony Green <green@redhat.com> 2.2-1
- Upgrade to ardour 2.2.  Wrap executable in a script.

* Fri Dec 21 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 2.1-4
- Fix building of ardour on alpha machines (bz 425987)
- Fix building with glib-2.15.0

* Wed Oct 10 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 2.1-3
- Fix finding of translations (bz 238552)
- Convert some documentation files to UTF-8

* Tue Oct  9 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 2.1-2
- Upgrade to latest upstream 2.1 (bz 238552)
- Merge with CCRMA ardour2 package
- Begin with a release of 2 to be higher then CCRMA's last EVR

* Wed May 02 2007 Anthony Green <green@redhat.com> 2.0-1
- Upgrade sources.

* Sat Jan 06 2007 Anthony Green <green@redhat.com> 0.99.3-8
- Enable optimization (oops).
- Add ardour-no-sse.patch to disable use of build-system dependent 
  hardware features (SSE, MMX, etc).

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 0.99.3-7
 - rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Tue Sep 19 2006 Anthony Green <green@redhat.com> 0.99.3-6
- Fix release tag.

* Mon Sep 18 2006 Anthony Green <green@redhat.com> 0.99.3-5.1
- Rebuild.

* Sat Sep  8 2006 Anthony Green <green@redhat.com> 0.99.3-5
- Install the templates.

* Sat Sep  2 2006 Anthony Green <green@redhat.com> 0.99.3-4
- Move .desktop file out of spec file to source dir.
- Add a couple of upstream patches (2 and 3)

* Sun Aug 13 2006 Anthony Green <green@redhat.com> 0.99.3-3
- Remove PlanetCCRMA changelogs (rpmlint was complaining)
- Escape macros in changelog.
- Remove useless rm in %%build section.
- Don't install useless README file.
- Clean up BuildRequires and %%files sections.

* Sat May 13 2006 Anthony Green <green@redhat.com> 0.99.3-2
- Conditionally apply ardour-lib64-ladspa.patch.

* Sat May 13 2006 Anthony Green <green@redhat.com> 0.99.3-1
- Update sources to 0.99.3.
- Add linudoc-tools dependency.
- Set USE_SSE_EVERYWHERE and BUILD_SSE_OPTIMIZATIONS at build time.
- Replace some macro command usage.

* Sat Apr 22 2006 Anthony Green <green@redhat.com> 0.99.2-3
- Use %%find_lang.

* Thu Apr 20 2006 Anthony Green <green@redhat.com> 0.99.2-2
- Fix ardour URL.  Add scons smp build flags.
- Own %%{_sysconfdir}/ardour.
- Standardize on $RPM_BUILD_ROOT usage.
- Remove gcc BuildRequires.

* Tue Apr 18 2006 Anthony Green <green@redhat.com> 0.99.2-1
- Update sources. Build for Fedora Extras. Derived from Fernando
  Lopez-Lezcano's PlanetCCRMA package.
